package com.vendor.loader.util;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.loader.Messages;
import com.vendor.loader.controler.GlobleControler;
import com.vendor.loader.model.PartitionItem;
import com.vendor.loader.struct.FileSystem;
import com.vendor.loader.struct.FlashType;
import com.vendor.loader.struct.UpgradeFileInfo;
import com.vendor.loader.struct.UpgradeInfo;
import com.vendor.loader.util.FileUtil;
import com.vendor.loader.util.InvalidDataFormatException;
import com.vendor.loader.util.StringUtil;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import org.apache.commons.configuration2.PropertiesConfiguration;
import org.apache.commons.configuration2.ex.ConfigurationException;
import org.eclipse.osgi.util.NLS;

public final class IniFileParser {
  private String downloadPid;
  
  private String downloadTableId;
  
  private String manufacturerId;
  
  private String softwareVersion;
  
  private String hardwareVersion;
  
  private String startSn;
  
  private String endSn;
  
  private String burnFileName;
  
  private String ts_File;
  
  private String usb_File;
  
  private ArrayList<UpgradeFileInfo> upgradFiles;
  
  public IniFileParser(String iniFilename) throws InvalidDataFormatException, ConfigurationException {
    try {
      if (!FileUtil.checkFilePath(iniFilename))
        return; 
    } catch (IOException e) {
      return;
    } 
    FileReader fileReader = null;
    BufferedReader bufferedReader = null;
    try {
      PropertiesConfiguration propertie = new PropertiesConfiguration();
      fileReader = new FileReader(iniFilename);
      bufferedReader = new BufferedReader(fileReader);
      propertie.read(bufferedReader);
      this.ts_File = propertie.getString("ts_file_name");
      this.usb_File = propertie.getString("usb_file_name");
      long bin_file_num = propertie.getLong("bin_file_num");
      if (bin_file_num == 0L)
        throw new InvalidDataFormatException(Messages.IniFileParser_FileNumberError); 
      this.downloadPid = propertie.getString("Download_PID");
      if (this.downloadPid == null)
        throw new InvalidDataFormatException(NLS.bind(Messages.IniFileParser_EmptyValue, "Download_PID")); 
      checkStringRange(this.downloadPid, 32L, 8190L, 


          
          NLS.bind(Messages.IniFileParser_ValueScopeError, new Object[] { "Download_PID", "0x20~0x1FFE" }));
      this.downloadTableId = propertie.getString("Download_TableId");
      if (this.downloadPid == null)
        throw new InvalidDataFormatException(NLS.bind(Messages.IniFileParser_EmptyValue, "Download_TableId")); 
      checkStringRange(this.downloadTableId, 64L, 255L, 


          
          NLS.bind(Messages.IniFileParser_ValueScopeError, new Object[] { "Download_TableId", "0x40~0xFF" }));
      this.manufacturerId = propertie.getString("manufacturer_ID");
      if (this.manufacturerId == null)
        throw new InvalidDataFormatException(NLS.bind(Messages.IniFileParser_EmptyValue, "manufacturer_ID")); 
      checkStringRange(this.manufacturerId, 0L, 65535L, 


          
          NLS.bind(Messages.IniFileParser_ValueScopeError, new Object[] { "manufacturer_ID", "0x0~0xFFFF" }));
      this.softwareVersion = propertie.getString("software_version");
      if (this.softwareVersion == null)
        throw new InvalidDataFormatException(NLS.bind(Messages.IniFileParser_EmptyValue, "software_version")); 
      checkStringRange(this.softwareVersion, 0L, 4294967294L, 


          
          NLS.bind(Messages.IniFileParser_ValueScopeError, new Object[] { "software_version", "0x0~0xFFFFFFFF" }));
      this.hardwareVersion = propertie.getString("hardware_version");
      if (this.hardwareVersion == null)
        throw new InvalidDataFormatException(NLS.bind(Messages.IniFileParser_EmptyValue, "hardware_version")); 
      checkStringRange(this.hardwareVersion, 0L, 4294967295L, 


          
          NLS.bind(Messages.IniFileParser_ValueScopeError, new Object[] { "hardware_version", "0x0~0xFFFFFFFF" }));
      this.startSn = propertie.getString("start_sn");
      if (this.startSn == null)
        throw new InvalidDataFormatException(NLS.bind(Messages.IniFileParser_EmptyValue, "start_sn")); 
      checkStringRange(this.startSn, 0L, 4294967295L, 


          
          NLS.bind(Messages.IniFileParser_ValueScopeError, new Object[] { "start_sn", "0x0~0xFFFFFFFF" }));
      this.endSn = propertie.getString("end_sn");
      if (this.endSn == null)
        throw new InvalidDataFormatException(NLS.bind(Messages.IniFileParser_EmptyValue, "end_sn")); 
      checkStringRange(this.endSn, 0L, 4294967295L, 


          
          NLS.bind(Messages.IniFileParser_ValueScopeError, new Object[] { "end_sn", "0x0~0xFFFFFFFF" }));
      this.burnFileName = propertie.getString("ts_file_name");
      if (this.burnFileName == null)
        this.burnFileName = "packer.ts"; 
      if (256L < bin_file_num)
        throw new InvalidDataFormatException(String.format(Messages.LoaderComposite_88, new Object[] { Integer.valueOf(256) })); 
      this.upgradFiles = new ArrayList<>();
      for (int i = 0; i < bin_file_num; i++) {
        FlashType flashType = FlashType.nand;
        long flashIndex = 0L;
        boolean select = false;
        long sel = propertie.getLong("flash_sel" + i + 1);
        if (sel == 1L) {
          select = true;
        } else {
          select = false;
        } 
        String PartitionName = propertie.getString("flash_PartitionName" + i + 1);
        int partitionversion = propertie.getInt("flash_PartitionVersion" + i + 1, 0);
        int partitionversiontag = propertie.getInt("flash_PartitionVersionTag" + i + 1, 0);
        String key = "bin_name" + i + 1;
        String partFilename = propertie.getString(key);
        if (partFilename == null || partFilename.isEmpty())
          throw new InvalidDataFormatException(NLS.bind(Messages.IniFileParser_EmptyValue, key)); 
        partFilename = StringUtil.removeQuotes(partFilename);
        partFilename = getFileName(iniFilename, partFilename);
        key = "flash_addr" + i + 1;
        long startAddr = propertie.getLong(key, 0L);
        key = "flash_type" + i + 1;
        long type = propertie.getLong(key, 0L);
        checkRange(type, 0L, 3L, 
            NLS.bind(Messages.IniFileParser_ErrorValue, key));
        flashType = FlashType.valueOf((int)type);
        key = "flash_system" + i + 1;
        String system = propertie.getString(key);
        if (system == null || system.isEmpty())
          throw new InvalidDataFormatException(NLS.bind(Messages.IniFileParser_EmptyValue, key)); 
        FileSystem fileSystem = FileSystem.valueOf(system);
        key = "flashindex" + i + 1;
        flashIndex = propertie.getLong(key, 0L);
        checkRange(type, 0L, 3L, 
            NLS.bind(Messages.IniFileParser_ErrorValue, key));
        if (fileSystem.equals(FileSystem.yaffs))
          flashIndex |= 0x10000L; 
        key = "file_length" + i + 1;
        long length = propertie.getLong(key, 0L);
        if (length == 0L)
          throw new InvalidDataFormatException(NLS.bind(Messages.IniFileParser_EmptyValue, key)); 
        int fileLength = (int)(new File(partFilename)).length();
        UpgradeFileInfo f = new UpgradeFileInfo(select, PartitionName, partitionversion, partitionversiontag, partFilename, startAddr, startAddr + length, flashType, fileSystem, flashIndex, fileLength, length);
        if (!FileUtil.checkAddressConflict(f, this.upgradFiles))
          this.upgradFiles.add(f); 
        if (this.ts_File != null)
          GlobleControler.intance
            .SOCT_TS = StringUtil.removeQuotes(this.ts_File); 
        if (this.usb_File != null)
          GlobleControler.intance.SOCT_USB = StringUtil.removeQuotes(this.usb_File); 
      } 
    } catch (IOException iOException) {
    
    } finally {
      try {
        if (bufferedReader != null)
          bufferedReader.close(); 
      } catch (IOException iOException) {}
      try {
        if (fileReader != null)
          fileReader.close(); 
      } catch (IOException iOException) {}
    } 
  }
  
  public IniFileParser(List<PartitionItem> load) throws IOException, InvalidDataFormatException {
    long bin_file_num = load.size();
    if (this.burnFileName == null)
      this.burnFileName = "packer.ts"; 
    if (256L < bin_file_num)
      throw new InvalidDataFormatException(String.format(Messages.LoaderComposite_88, new Object[] { Integer.valueOf(256) })); 
    this.upgradFiles = new ArrayList<>();
    for (int i = 0; i < load.size(); i++) {
      PartitionItem item = load.get(i);
      FlashType flashType = FlashType.nand;
      long flashIndex = 0L;
      String partFilename = "";
      File file = item.getFile();
      if (file != null)
        partFilename = item.getFile().getCanonicalPath(); 
      long startAddr = item.getStart();
      flashType = item.getFlashType();
      FileSystem fileSystem = item.getFileSystem();
      if (FileSystem.yaffs.equals(fileSystem))
        flashIndex |= 0x10000L; 
      long length = item.getLength();
      int fileLength = (int)(new File(partFilename)).length();
      UpgradeFileInfo f = new UpgradeFileInfo(item.isChecked(), item.getName(), item.getPartitionVersione(), item.getPartitionVersionTag(), partFilename, startAddr, startAddr + length, flashType, fileSystem, flashIndex, fileLength, length);
      f.setSel(item.isChecked());
      f.setPartitionName(item.getName());
      if (!FileUtil.checkAddressConflict(f, this.upgradFiles))
        this.upgradFiles.add(f); 
      if (this.ts_File != null)
        GlobleControler.intance
          .SOCT_TS = StringUtil.removeQuotes(this.ts_File); 
      if (this.usb_File != null)
        GlobleControler.intance
          .SOCT_USB = StringUtil.removeQuotes(this.usb_File); 
    } 
  }
  
  private String getFileName(String iniFilename, String partFilename) {
    int iniFilenameLast = iniFilename.lastIndexOf("\\");
    if (iniFilenameLast == -1)
      iniFilenameLast = iniFilename.lastIndexOf("/"); 
    if (iniFilenameLast != -1)
      iniFilename = iniFilename.substring(0, iniFilenameLast); 
    iniFilename = iniFilename.replace("\\", "/");
    int lastIndexOf = partFilename.lastIndexOf("\\");
    if (lastIndexOf == -1)
      lastIndexOf = partFilename.lastIndexOf("/"); 
    String newPath = null;
    if (lastIndexOf != -1 || partFilename.trim().length() == 0) {
      if (partFilename.startsWith("./")) {
        partFilename = iniFilename + "/" + iniFilename;
        newPath = partFilename;
      } else {
        newPath = partFilename;
      } 
    } else {
      newPath = iniFilename + "/" + iniFilename;
    } 
    return newPath;
  }
  
  public ArrayList<UpgradeFileInfo> getUpgradFiles() {
    return this.upgradFiles;
  }
  
  public UpgradeInfo getUpgradeInfo() {
    UpgradeInfo info = new UpgradeInfo();
    if (this.downloadPid != null)
      info.setDownloadPid((int)StringUtil.convertString(this.downloadPid)); 
    if (this.downloadTableId != null)
      info.setDownloadTableId(
          (int)StringUtil.convertString(this.downloadTableId)); 
    if (this.manufacturerId != null)
      info.setManufacturerId(
          (int)StringUtil.convertString(this.manufacturerId)); 
    if (this.hardwareVersion != null)
      info.setHardwareVersion(
          (int)StringUtil.convertString(this.hardwareVersion)); 
    if (this.softwareVersion != null)
      info.setSoftwareVersion(
          (int)StringUtil.convertString(this.softwareVersion)); 
    if (this.startSn != null)
      info.setStartSn((int)StringUtil.convertString(this.startSn)); 
    if (this.endSn != null)
      info.setEndSn((int)StringUtil.convertString(this.endSn)); 
    return info;
  }
  
  private void checkRange(long value, long min, long max, String errorMsg) throws InvalidDataFormatException {
    if (value < min || value > max)
      throw new InvalidDataFormatException(errorMsg); 
  }
  
  private void checkStringRange(String input, long min, long max, String errorMsg) throws InvalidDataFormatException {
    long value = StringUtil.convertString(input);
    if (value < min || value > max)
      throw new InvalidDataFormatException(errorMsg); 
  }
  
  public String getDownloadPid() {
    return this.downloadPid;
  }
  
  public String getDownloadTableId() {
    return this.downloadTableId;
  }
  
  public String getManufacturerId() {
    return this.manufacturerId;
  }
  
  public String getSoftwareVersion() {
    return this.softwareVersion;
  }
  
  public String getHardwareVersion() {
    return this.hardwareVersion;
  }
  
  public String getStartSn() {
    return this.startSn;
  }
  
  public String getEndSn() {
    return this.endSn;
  }
}
